# Changelog

All notable changes to this project will be documented in this file.

## [0.1.4] - 2025-6-30

- Enable tesseract auto-installation on Windows 
- Better error handling for Mac

## [0.1.2] - 2025-5-27

This package is a modified version of [rjn32s/mcp-ocr](https://github.com/rjn32s/mcp-ocr) for supporting Foundry Local. Changes included, 
- remove image bytes input type
- better error handling 
